@@ -12,6 +12,7 @@ import json
 import logging
 import math
 import re
+import time
 import traceback
 import urllib.parse
 
@@ -53,35 +54,49 @@ class BaseHandler(tornado.web.RequestHandler):
         else:
             return '.'.join(arr[-2:])
 
-    def check_referer(self, hosts=None, address=None, allow_blank=True, raise_error=True):
+    def check_referer(self, referers=None, allow_blank=True, raise_error=True):
         referer = urllib.parse.urlparse(self.referer).netloc
         if not referer and allow_blank:
             return True
-        domains = []
-        if isinstance(hosts, str):
-            domains.append(hosts)
-        elif isinstance(hosts, list):
-            domains.extend(hosts)
-        if address:
-            if re.match(r'https?://', address):
-                domains.append(urllib.parse.urlparse(address).netloc)
-            else:
-                domains.append(address)
-        else:
-            domains.append(self.host)
 
-        for domain in domains:
-            if domain.startswith('*') and referer.endswith(domain[1:]):
+        if isinstance(referers, str):
+            referers = [referers]
+
+        for domain in referers:
+            if domain.startswith('*.') and referer.endswith(domain[2:]):
+                return True
+            elif domain.startswith('*') and referer.endswith(domain[1:]):
                 return True
             elif referer == domain:
                 return True
 
         if raise_error:
-            self.logger.warning(f'authorized domains: {domains}, referer: {self.referer}')
+            self.logger.warning(f'authorized referers: {referers}, referer: {self.referer}')
             raise tornado.web.HTTPError(403)
         else:
             return False
 
+    async def check_sign(self):
+        if not (self.args.t and self.args.n and self.args.s):
+            raise tornado.web.HTTPError(403)
+
+        if time.time() - int(self.args.t, 16) >= 300:
+            raise tornado.web.HTTPError(403)
+
+        if self.args.s != hashlib.md5(f'digua_{self.args.t}_{self.args.n}'.encode()).hexdigest():
+            raise tornado.web.HTTPError(403)
+
+        '''
+        key = f'{self.prefix}_{self.args.s}'
+        value = hashlib.md5(f'{self.ua}_{self.ip}_{self.args.s}'.encode()).hexdigest()
+        check = await self.rd.get(key)
+        self.logger.info(f'check: {check}, value: {value}, {self.args}')
+        if check is None:
+            await self.rd.setex(key, 3600, value)
+        elif check != value:
+            raise tornado.web.HTTPError(403)
+        '''
+
     async def get_current_user(self):
         token = self.get_cookie('token', self.args.token)
         if token and hasattr(self.app, 'db') and isinstance(self.app.db, (Mongo, Motor)):
@@ -106,8 +121,8 @@ class BaseHandler(tornado.web.RequestHandler):
 
     @cached_property
     def mobile(self):
-        mobile_re = re.compile(r'(iOS|iPhone|Android|Windows Phone|webOS|BlackBerry|Symbian|Opera Mobi|UCBrowser|MQQBrowser|Mobile|Touch)', re.I)
-        return True if mobile_re.search(self.ua) else False
+        regexp = re.compile(r'Mobile|Android|iPhone|Windows Phone|iPad|Opera Mobi|iPod|UCBrowser|MQQBrowser|Quark|MicroMessenger', re.I)
+        return True if regexp.search(self.ua) else False
 
     @cached_property
     def weixin(self):
@@ -125,7 +140,7 @@ class BaseHandler(tornado.web.RequestHandler):
             self.set_header('Content-Type', 'application/json')
         return super().write(chunk)
 
-    def write_error(self, status_code, **kwargs):
+    def write_error2(self, status_code, **kwargs):
         if kwargs.get('exc_info'):
             msg = ''.join(traceback.format_exception(*kwargs["exc_info"]))
             self.logger.error(msg)
@@ -165,7 +180,7 @@ class BaseHandler(tornado.web.RequestHandler):
         query = urllib.parse.parse_qs(ret.query)
         query.update(kwargs)
         return urllib.parse.urlunparse((ret.scheme, ret.netloc, ret.path, ret.params,
-                                       urllib.parse.urlencode(query, doseq=True), ret.fragment))
+                                        urllib.parse.urlencode(query, doseq=True), ret.fragment))
 
     def filter(self, query, include=[], exclude=[]):
         exclude = list(set(exclude) | set(['page', 'size', 'sort', 'order', 'f']))
