@@ -10,6 +10,7 @@ import json
 import logging
 import re
 from configparser import ConfigParser
+from pathlib import Path
 
 import yaml
 
@@ -20,20 +21,20 @@ class Config(Dict):
 
     def __init__(self, config=None, guess=True, parse=True):
         if config is not None:
-            self._load_cfg(config)
+            self.update(self._load_cfg(config))
 
         if parse:
             parser = argparse.ArgumentParser()
             parser.add_argument('--config', type=str, default=None)
             args, _ = parser.parse_known_args()
             if args.config:
-                self._load_cfg(args.config)
-
-            for key, value in self.items():
-                self._add_args(parser, key, value)
+                self.update(self._load_cfg(args.config))
 
             parser = argparse.ArgumentParser()
+            for key, value in self.items():
+                self._add_args(parser, key, value)
             args, params = parser.parse_known_args()
+
             if params and guess:
                 logger = logging.getLogger()
                 parsed_params = self._parse(params)
@@ -46,25 +47,39 @@ class Config(Dict):
     def _load_ini(self, config):
         conf = ConfigParser()
         conf.read(config)
-        opt = {}
+        cfg = Dict()
         for section in conf.sections():
-            opt[section] = {}
+            cfg[section] = Dict()
             for key, value in conf.items(section):
-                opt[section][key] = self._convert(value)
-        return opt
+                cfg[section][key] = self._convert(value)
+        return cfg
 
     def _load_cfg(self, config):
+        cfg = Dict()
         if isinstance(config, dict):
-            self.update(Dict(config))
+            cfg.update(Dict(config))
         elif config.endswith('.ini'):
-            self.update(Dict(self._load_ini(config)))
+            cfg.update(Dict(self._load_ini(config)))
         elif config.endswith('.json'):
-            self.update(Dict(json.load(open(config))))
+            cfg.update(Dict(json.load(open(config))))
         elif config.endswith('.yaml') or config.endswith('.yml'):
-            self.update(Dict(yaml.load(open(config))))
+            cfg.update(Dict(yaml.load(open(config))))
         else:
             raise TypeError(f'{config} must be dict, ini, json or yaml')
 
+        if cfg.extends:
+            base = Dict()
+            root = Path(config).parent
+            if isinstance(cfg.extends, list):
+                for x in cfg.extends:
+                    base.update(self._load_cfg(str(root / x)))
+            elif isinstance(cfg.extends, str):
+                base.update(self._load_cfg(str(root / cfg.extends)))
+            base.update(cfg)
+            cfg.update(base)
+
+        return cfg
+
     def _convert(self, value):
         if re.match(r'^-?[\d]+$', value):
             return int(value)
