@@ -890,7 +890,7 @@ class Chrome(webdriver.Chrome):
 
     def __init__(self, path=None, headless=False, proxy=None, mobile=False):
         options = webdriver.ChromeOptions()
-        options.add_experimental_option("excludeSwitches", ["ignore-certificate-errors"])
+        options.add_experimental_option('excludeSwitches', ['enable-automation', 'ignore-certificate-errors'])
         options.add_experimental_option('w3c', False)
         options.add_argument('disable-infobars')
         options.add_argument('lang=zh_CN.UTF-8')
